import { IStringFormatParser, IStringFormatter, TStringTransformer } from "../StringFormat";
/**
 * Support C-Style String formatting
 * The following formats are supported:
 * - %s - string
 * - %d - integer
 * - %u - unicode
 * - %e - exponential
 * - %f - floating point
 * - %c - character
 * - %b - binary
 * - %o - octal
 * - %x - hexadecimal
 * - %X - hexadecimal
 *
 * @see https://github.com/tmaeda1981jp/string-format-js for C-Style formatting
 */
export default class CStyleFormatter implements IStringFormatter {
    get name(): string;
    /**
     * List of formats supported by the C-Style formatter out of the box
     */
    private static DEFAULT_FORMAT_PARSERS;
    /**
     * The regex used to test if a string is a format string
     * This populates RegExp.$1 with the format identifier
     */
    private static IDENTIFIER_REGEX;
    private formatParsers;
    constructor();
    /**
     * @inheritdoc
     * @since 0.1.0
     */
    isFormatParserSupported(): boolean;
    /**
     * @inheritdoc
     * @param formatParser the format parser
     * @since 0.1.0
     */
    addFormatParser(formatParser: IStringFormatParser): void;
    /**
     * @inheritdoc
     * @param {string} identifier the format parser identifier
     * @returns {boolean} true if the format parser is available
     * @since 0.1.0
     */
    hasFormatParser(identifier: string): boolean;
    /**
     * @inheritdoc
     * @param formatParserName the name of the format parser
     * @since 0.1.0
     */
    removeFormatParser(formatParserName: string): void;
    /**
     * @inheritdoc
     * @since 0.1.0
     * @returns {false} false transformers feature is not supported by the C-Style formatter
     */
    isTransformersSupported(): boolean;
    /**
     * @inheritdoc
     * @param key the transformer key
     * @param transformer Transformer
     * @since 0.1.0
     * @throws {Error} if the transformer is not supported
     */
    addTransformer(key: string, transformer: TStringTransformer): void;
    /**
     * @inheritdoc
     * @param key the transformer key
     * @returns {boolean} true if the transformer is available
     * @since 0.1.0
     */
    hasTransformer(key: string): boolean;
    /**
     * @inheritdoc
     * @param key the transformer key
     * @since 0.1.0
     * @throws {Error} if the transformer is not supported
     */
    removeTransformer(key: string): void;
    /**
     * @inheritdoc
     * @param {string} input the input string
     * @param {any[]} param the parameters
     * @returns {[boolean, string]} is processed, the formatted string
     * @since 0.1.0
     * @throws {Error} if the input string is not a format string
     */
    format(input: string, ...params: any[]): [boolean, string];
}
//# sourceMappingURL=CStyleFormatter.d.ts.map