import { IStringFormatParser, IStringFormatter, TStringTransformer } from "../StringFormat";
/**
 * Python style string formatter
 *
 * @class PyStyleFormatter
 * @implements {IStringFormatter}
 * @see {@link https://docs.python.org/3/library/string.html#format-string-syntax}
 * @see {@link https://github.com/davidchambers/string-format}
 */
export default class PyStyleFormatter implements IStringFormatter {
    private static readonly IDENTIFIER_REGEX;
    /**
     * List of transformers
     */
    private transformers;
    constructor();
    /**
     * @inheritdoc
     */
    get name(): string;
    /**
     * @inheritdoc
     * @since 0.1.0
     */
    isFormatParserSupported(): boolean;
    /**
     * @inheritdoc
     * @param formatParser the format parser
     * @since 0.1.0
     */
    addFormatParser(formatParser: IStringFormatParser): void;
    /**
     * @inheritdoc
     * @param {string} identifier the format parser identifier
     * @returns {boolean} true if the format parser is available
     * @since 0.1.0
     */
    hasFormatParser(formatParserName: string): boolean;
    /**
     * @inheritdoc
     * @param formatParserName the name of the format parser
     * @since 0.1.0
     */
    removeFormatParser(formatParserName: string): void;
    /**
     * @inheritdoc
     * @since 0.1.0
     * @returns {false} false transformers feature is not supported by the C-Style formatter
     */
    isTransformersSupported(): boolean;
    /**
     * @inheritdoc
     * @param key the transformer key
     * @param transformer Transformer
     * @since 0.1.0
     * @throws {Error} if the transformer is not supported
     */
    addTransformer(key: string, transformer: TStringTransformer): void;
    /**
     * @inheritdoc
     * @param key the transformer key
     * @returns {boolean} true if the transformer is available
     * @since 0.1.0
     */
    hasTransformer(key: string): boolean;
    /**
     * @inheritdoc
     * @param key the transformer key
     * @since 0.1.0
     * @throws {Error} if the transformer is not supported
     */
    removeTransformer(key: string): void;
    /**
     * @inheritdoc
     * @param {string} input the input string
     * @param {any[]} param the parameters
     * @returns {[boolean, string]} is processed, the formatted string
     * @since 0.1.0
     * @throws {Error} if the input string is not a format string
     */
    format(input: string, ...param: any[]): [boolean, string];
}
//# sourceMappingURL=PyStyleFormatter.d.ts.map